==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/kbibtexentrywidgettab.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXENTRYWIDGETTAB_H
#define KBIBTEXENTRYWIDGETTAB_H

#include <qwidget.h>

class QLineEdit;
class QSpinBox;
class QComboBox;
class QListView;
class QListViewItem;
class QTextEdit;
class QStringList;
class BibTeXEntry;
class KBibTeXEditListBox;
class KBibTeXEntryWidget;

class KBibTeXEntryWidgetTab : public QWidget
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetTab( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );

    ~KBibTeXEntryWidgetTab();

    virtual void setupGUI();
    virtual void getEntryData( BibTeXEntry *entry );
    virtual bool setEntryData( BibTeXEntry *entry );
    virtual void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll , bool isReadWrite );
    virtual void updateWarnings();

protected:
    bool setEntryDataSpinBox( BibTeXEntry *entry, QSpinBox *sbx, BibTeXEntryField::FieldType fieldType );
    bool setEntryDataText( BibTeXEntry *entry, const QString& text, BibTeXEntryField::FieldType fieldType );
    void setWidgetStatus( QWidget* widget, BibTeXEntryField::FieldRequireStatus requiredStatus, bool enableAll, bool isReadWrite );
    void addWarning( BibTeXEntryField::FieldType fieldType, const QString& label, bool valid, QWidget *widget );
    void installEventFilters( QWidget *parent );

    KBibTeXEntryWidget *m_entryWidget;
};

// ============================================================================================

class KBibTeXEntryWidgetTitle: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetTitle( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetTitle();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

private:
    QLineEdit* m_lineEditTitle;
    QLineEdit* m_lineEditBookTitle;
    QLineEdit* m_lineEditSeries;

};

// ============================================================================================

class KBibTeXEntryWidgetAuthor: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetAuthor( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetAuthor();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

private:
    KBibTeXEditListBox *m_editListBoxAuthor;
    KBibTeXEditListBox *m_editListBoxEditor;
};

// ============================================================================================

class KBibTeXEntryWidgetPublication: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetPublication( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetPublication();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

private:
    QLineEdit* m_lineEditPages;
    QLineEdit* m_lineEditVolume;
    QLineEdit* m_lineEditEdition;
    QComboBox* m_comboBoxMonth;
    QSpinBox* m_spinBoxYear;
    QLineEdit* m_lineEditChapter;
    QLineEdit* m_lineEditNumber;
    QLineEdit* m_lineEditOrganization;
    QLineEdit* m_lineEditSchool;
    QLineEdit* m_lineEditCrossRef;
    QLineEdit* m_lineEditPublisher;
    QLineEdit* m_lineEditInstitution;
    QLineEdit* m_lineEditAddress;
    QLineEdit* m_lineEditHowPublished;
    QLineEdit* m_lineEditISBN;
    QLineEdit* m_lineEditISSN;
    QLineEdit* m_lineEditJournal;

};

// ============================================================================================

class KBibTeXEntryWidgetMisc: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetMisc( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetMisc();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

private:
    QLineEdit* m_lineEditKey;
    QLineEdit* m_lineEditNote;
    QLineEdit* m_lineEditType;
    QLineEdit* m_lineEditAnnote;
    QLineEdit* m_lineEditURL;
    QPushButton *m_pushButtonURLtoNote;
    QPushButton *m_pushButtonOpenURL;
    QTextEdit* m_textEditAbstract;

private slots:
    void applyURLtoNode();
    void openURL();
};

// ============================================================================================

class KBibTeXEntryWidgetUserFields: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetUserFields( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetUserFields();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

private:
    QPushButton* m_pushButtonUserAdd;
    QListView* m_listViewUserFields;
    QLineEdit* m_lineEditUserKey;
    QTextEdit* m_textEditUserValue;
    QPushButton* m_pushButtonUserDelete;
    QStringList *m_deletedUserFields;
    QPushButton *m_pushButtonUserOpen;

private slots:
    void userFieldExecute( QListViewItem* item = NULL );
    void userNameChanged( const QString& newText );
    void userAddClicked( );
    void userDeleteClicked();
    void userOpenClicked();
};

// ============================================================================================

class KBibTeXEntryWidgetSource: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetSource( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetSource();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

    bool isModified();
    void setModified( bool modified );

private:
    QTextEdit *m_textEditSource;

};

#endif

==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/kbibtexentrywidgettab.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXENTRYWIDGETTAB_H
#define KBIBTEXENTRYWIDGETTAB_H

#include <qwidget.h>

class QLineEdit;
class QSpinBox;
class QComboBox;
class QListView;
class QListViewItem;
class QTextEdit;
class QStringList;
class BibTeXEntry;
class KBibTeXEditListBox;
class KBibTeXEntryWidget;

class KBibTeXEntryWidgetTab : public QWidget
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetTab( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );

    ~KBibTeXEntryWidgetTab();

    virtual void setupGUI();
    virtual void getEntryData( BibTeXEntry *entry );
    virtual bool setEntryData( BibTeXEntry *entry );
    virtual void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll , bool isReadWrite );
    virtual void updateWarnings();

protected:
    bool setEntryDataSpinBox( BibTeXEntry *entry, QSpinBox *sbx, BibTeXEntryField::FieldType fieldType );
    bool setEntryDataText( BibTeXEntry *entry, const QString& text, BibTeXEntryField::FieldType fieldType, bool isString = FALSE );
    void setWidgetStatus( QWidget* widget, BibTeXEntryField::FieldRequireStatus requiredStatus, bool enableAll, bool isReadWrite );
    void addMissingWarning( BibTeXEntryField::FieldType fieldType, const QString& label, bool valid, QWidget *widget );
    void addStringKeyError( const QString& label, bool violation, QWidget *widget );
    void installEventFilters( QWidget *parent );

    KBibTeXEntryWidget *m_entryWidget;
};

// ============================================================================================

class KBibTeXEntryWidgetTitle: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetTitle( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetTitle();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

private:
    QLineEdit* m_lineEditTitle;
    QPushButton *m_pushButtonTitleString;
    QLineEdit* m_lineEditBookTitle;
    QPushButton *m_pushButtonBookTitleString;
    QLineEdit* m_lineEditSeries;
    QPushButton *m_pushButtonSeriesString;

};

// ============================================================================================

class KBibTeXEntryWidgetAuthor: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetAuthor( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetAuthor();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

private:
    KBibTeXEditListBox *m_editListBoxAuthor;
    KBibTeXEditListBox *m_editListBoxEditor;
};

// ============================================================================================

class KBibTeXEntryWidgetPublication: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetPublication( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetPublication();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

private:
    QLineEdit* m_lineEditHowPublished;
    QPushButton *m_pushButtonHowPublishedString;
    QLineEdit* m_lineEditPublisher;
    QPushButton *m_pushButtonPublisherString;
    QLineEdit* m_lineEditOrganization;
    QPushButton *m_pushButtonOrganizationString;
    QLineEdit* m_lineEditInstitution;
    QPushButton *m_pushButtonInstitutionString;
    QLineEdit* m_lineEditSchool;
    QPushButton *m_pushButtonSchoolString;
    QLineEdit* m_lineEditAddress;
    QPushButton *m_pushButtonAddressString;
    QLineEdit* m_lineEditJournal;
    QPushButton *m_pushButtonJournalString;
    QLineEdit* m_lineEditPages;
    QLineEdit* m_lineEditEdition;
    QLineEdit* m_lineEditChapter;
    QLineEdit* m_lineEditVolume;
    QComboBox* m_comboBoxMonth;
    QSpinBox* m_spinBoxYear;
    QLineEdit* m_lineEditNumber;
    QLineEdit* m_lineEditCrossRef;
    QLineEdit* m_lineEditISBN;
    QLineEdit* m_lineEditISSN;

};

// ============================================================================================

class KBibTeXEntryWidgetMisc: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetMisc( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetMisc();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

private:
    QLineEdit* m_lineEditKey;
    QLineEdit* m_lineEditNote;
    QLineEdit* m_lineEditType;
    QLineEdit* m_lineEditAnnote;
    QLineEdit* m_lineEditURL;
    QPushButton *m_pushButtonURLtoNote;
    QPushButton *m_pushButtonOpenURL;
    QTextEdit* m_textEditAbstract;

private slots:
    void applyURLtoNode();
    void openURL();
};

// ============================================================================================

class KBibTeXEntryWidgetUserFields: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetUserFields( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetUserFields();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );

public slots:
    void updateWarnings();

private:
    QPushButton* m_pushButtonUserAdd;
    QListView* m_listViewUserFields;
    QLineEdit* m_lineEditUserKey;
    QTextEdit* m_textEditUserValue;
    QPushButton* m_pushButtonUserDelete;
    QStringList *m_deletedUserFields;
    QPushButton *m_pushButtonUserOpen;

private slots:
    void userFieldExecute( QListViewItem* item = NULL );
    void userNameChanged( const QString& newText );
    void userAddClicked( );
    void userDeleteClicked();
    void userOpenClicked();
};

// ============================================================================================

class KBibTeXEntryWidgetSource: public KBibTeXEntryWidgetTab
{
    Q_OBJECT
public:
    KBibTeXEntryWidgetSource( KBibTeXEntryWidget *entryWidget, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXEntryWidgetSource();

    void setupGUI();
    void getEntryData( BibTeXEntry *entry );
    bool setEntryData( BibTeXEntry *entry );
    void changeEntryType( BibTeXEntry::EntryType entryType, bool enableAll, bool isReadWrite );
    void updateWarnings();

    bool isModified();
    void setModified( bool modified );

private:
    QTextEdit *m_textEditSource;

};

#endif
